summaryrefslogtreecommitdiffstats
path: root/src/H5Pdcpl.c
diff options
context:
space:
mode:
authorRaymond Lu <songyulu@hdfgroup.org>2003-02-12 20:07:21 (GMT)
committerRaymond Lu <songyulu@hdfgroup.org>2003-02-12 20:07:21 (GMT)
commitd2bfd727ca0e9f298598b723d20faef3edf7b582 (patch)
tree0805568cda4cfea7021f770c22b9f7386829e6c3 /src/H5Pdcpl.c
parent2f8719efde2cb32cd84eaac18603464b3328c199 (diff)
downloadhdf5-d2bfd727ca0e9f298598b723d20faef3edf7b582.zip
hdf5-d2bfd727ca0e9f298598b723d20faef3edf7b582.tar.gz
hdf5-d2bfd727ca0e9f298598b723d20faef3edf7b582.tar.bz2
[svn-r6400]
Purpose: Change feature Description: Switch to Fletcher32 from Adler32 checksum Platforms tested: arabica, eirene, modi4 Misc. update: MANIFEST and RELEASE.txt updated.
Diffstat (limited to 'src/H5Pdcpl.c')
-rw-r--r--src/H5Pdcpl.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/H5Pdcpl.c b/src/H5Pdcpl.c
index efcd8c6..708506c 100644
--- a/src/H5Pdcpl.c
+++ b/src/H5Pdcpl.c
@@ -802,9 +802,9 @@ done:
/*-------------------------------------------------------------------------
- * Function: H5Pset_adler32
+ * Function: H5Pset_fletcher32
*
* Purpose: Sets Adler32 checksum of EDC for a dataset creation
* property list.
*
* Return: Non-negative on success/Negative on failure
@@ -817,23 +817,23 @@ done:
*-------------------------------------------------------------------------
*/
herr_t
-H5Pset_adler32(hid_t plist_id)
+H5Pset_fletcher32(hid_t plist_id)
{
H5O_pline_t pline;
H5P_genplist_t *plist; /* Property list pointer */
herr_t ret_value=SUCCEED; /* return value */
- FUNC_ENTER_API(H5Pset_adler32, FAIL);
+ FUNC_ENTER_API(H5Pset_fletcher32, FAIL);
H5TRACE1("e","i",plist_id);
/* Get the plist structure */
if(NULL == (plist = H5P_object_verify(plist_id,H5P_DATASET_CREATE)))
HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID");
/* Add the Adler32 checksum as a filter */
if(H5P_get(plist, H5D_CRT_DATA_PIPELINE_NAME, &pline) < 0)
HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get pipeline");
- if(H5Z_append(&pline, H5Z_FILTER_ADLER32, H5Z_FLAG_MANDATORY, 0, NULL)<0)
+ if(H5Z_append(&pline, H5Z_FILTER_FLETCHER32, H5Z_FLAG_MANDATORY, 0, NULL)<0)
HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, FAIL, "unable to add deflate filter to pipeline");
if(H5P_set(plist, H5D_CRT_DATA_PIPELINE_NAME, &pline) < 0)
HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, FAIL, "unable to set pipeline");
@@ -802,9 +802,9 @@ done:
*
- * Purpose: Sets Adler32 checksum of EDC for a dataset creation
+ * Purpose: Sets Fletcher32 checksum of EDC for a dataset creation
* property list.
*
@@ -817,23 +817,23 @@ done:
if(NULL == (plist = H5P_object_verify(plist_id,H5P_DATASET_CREATE)))
HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID");
- /* Add the Adler32 checksum as a filter */
+ /* Add the Fletcher32 checksum as a filter */
if(H5P_get(plist, H5D_CRT_DATA_PIPELINE_NAME, &pline) < 0)
HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get pipeline");